@@ -1,5 +1,5 @@
 # $File: //depot/cpanplus/dist/lib/CPANPLUS/Internals/Extract.pm $
-# $Revision: #6 $ $Change: 7741 $ $DateTime: 2003/08/27 20:36:54 $
+# $Revision: #8 $ $Change: 10305 $ $DateTime: 2004/03/03 11:54:09 $
 
 #######################################################
 ###            CPANPLUS/Internals/Extract.pm        ###
@@ -63,6 +63,10 @@ sub _extract {
                    $args->{data}->package,
                );
 
+    # We're going to do some chdir'ing, so make sure we're using an
+    # absolute filename.
+    $file = File::Spec->rel2abs($file);
+
     unless( -s $file ) {
         $err->trap( error => loc("%1 has zero size! Can not extract!", $file) );
         return 0;
@@ -78,7 +82,7 @@ sub _extract {
                 (ref $args->{data} ? $args->{data}->status->extract : '');
 
 
-    if ( $loc and !$force ) {
+    if ( $loc and -d $loc and !$force ) {
         $err->inform(
                 msg     => loc("Already extracted '%1' to '%2'. Won't extract again without force", $file, $loc),
                 quiet   => !$verbose,
