@@ -1,5 +1,5 @@
 # $File: //depot/cpanplus/dist/lib/CPANPLUS/Shell/Default.pm $
-# $Revision: #16 $ $Change: 7813 $ $DateTime: 2003/08/31 16:43:01 $
+# $Revision: #20 $ $Change: 9271 $ $DateTime: 2003/12/11 21:14:34 $
 
 ##################################################
 ###            CPANPLUS/Shell/Default.pm       ###
@@ -22,7 +22,7 @@ BEGIN {
     $VERSION    =   '0.03';
 }
 
-use CPANPLUS::Shell;
+use CPANPLUS::Shell ();
 use CPANPLUS::Backend;
 use CPANPLUS::I18N;
 use CPANPLUS::Tools::Term;
@@ -432,7 +432,7 @@ sub _input_loop {
             
             my $flag;
             for ( @list ) { 
-                $flag++ unless $href->rv->{$_} 
+                $flag++ unless ref $href->rv && $href->rv->{$_} 
             }
             
             if( $href->ok and !$flag ) {
@@ -989,6 +989,9 @@ sub _ask_report {
 
     my $args = check( $tmpl, \%hash ) or return undef;
 
+    # wise defaults for specific grades that shouldn't bother users about
+    return 'n' if $args->{grade} =~ /^unknown|na$/;
+    return 'y' if $args->{grade} =~ /pass/;
 
     return 'n' unless UNIVERSAL::can($self->term, 'ask_yn');
     return $self->term->ask_yn(
